class AdaptorError(Exception):
    pass


class FieldError(AdaptorError, ValueError):
    pass


class ForeignKeyFieldError(FieldError):
    def __init__(self, msg, model, value):
        self.model = model
        self.value = value
        self.msg = msg
        super(ForeignKeyFieldError, self).__init__(self.msg)


class FieldValueMissing(FieldError):
    def __init__(self, field_name):
        super(FieldValueMissing, self).__init__("No value found for field %s" % field_name)


class ChoiceError(AdaptorError, ValueError):
    pass





import re

class GenericRegexValidator(object):
    def validate(self, value):
        return bool(re.match(self.regex, value))

def RegexValidator(name, regex):
    return type(name, (GenericRegexValidator,), {'regex':regex})
    



#!/usr/bin/env python
import os
from setuptools import setup

def read(fname):
    return open(os.path.join(os.path.dirname(__file__), fname)).read()

setup(name='django-adaptors',
      version='0.2.3',
      description='Convert CSV/XML files into python object or django model',
      author='Anthony Tresontani',
      author_email='dev.tresontani@gmail.com',
      long_description=read('README.txt'),
      license="BSD",
      keywords="CSV XML Django adaptor",
      packages=['adaptor'],
      install_requires=[
          'lxml==2.3.4',
          'Django==1.4',
      ],
      classifiers=[
        "Development Status :: 3 - Alpha",
        "Topic :: Utilities",
        "License :: OSI Approved :: BSD License",
    ],
)
